@@ -1,9 +1,8 @@
 package HTTP::OAI;
 
 use strict;
-use warnings;
 
-our $VERSION = '3.21';
+our $VERSION = '3.22';
 
 # perlcore
 use Carp;
@@ -23,6 +22,9 @@ use XML::LibXML::SAX;
 use XML::LibXML::SAX::Parser;
 use XML::LibXML::SAX::Builder;
 
+# debug
+use HTTP::OAI::Debug;
+
 # oai data objects
 use HTTP::OAI::Encapsulation; # Basic XML handling stuff
 use HTTP::OAI::Metadata; # Super class of all data objects
@@ -55,6 +57,15 @@ use HTTP::OAI::Repository;
 
 $HTTP::OAI::Harvester::VERSION = $VERSION;
 
+if( $ENV{HTTP_OAI_TRACE} )
+{
+	HTTP::OAI::Debug::level( '+trace' );
+}
+if( $ENV{HTTP_OAI_SAX_TRACE} )
+{
+	HTTP::OAI::Debug::level( '+sax' );
+}
+
 1;
 
 __END__
